==> conductor-common-2.0.1-sources.jar: com/netflix/conductor/common/metadata/workflow/TaskType.java <==
package com.netflix.conductor.common.metadata.workflow;

import com.github.vmg.protogen.annotations.ProtoEnum;

@ProtoEnum
public enum TaskType {

    SIMPLE(true),
    DYNAMIC(true),
    FORK_JOIN(true),
    FORK_JOIN_DYNAMIC(true),
    DECISION(true),
    JOIN(true),
    SUB_WORKFLOW(true),
    EVENT(true),
    WAIT(true),
    USER_DEFINED(false);

    /**
     * TaskType constants representing each of the possible enumeration values.
     * Motivation: to not have any hardcoded/inline strings used in the code.
     * Example of use: CoreModule
     */
    public static final String TASK_TYPE_DECISION = "DECISION";
    public static final String TASK_TYPE_DYNAMIC = "DYNAMIC";
    public static final String TASK_TYPE_JOIN = "JOIN";
    public static final String TASK_TYPE_FORK_JOIN_DYNAMIC = "FORK_JOIN_DYNAMIC";
    public static final String TASK_TYPE_EVENT = "EVENT";
    public static final String TASK_TYPE_WAIT = "WAIT";
    public static final String TASK_TYPE_SUB_WORKFLOW = "SUB_WORKFLOW";
    public static final String TASK_TYPE_FORK_JOIN = "FORK_JOIN";
    public static final String TASK_TYPE_USER_DEFINED = "USER_DEFINED";
    public static final String TASK_TYPE_SIMPLE = "SIMPLE";

    private boolean isSystemTask;

    TaskType(boolean isSystemTask) {
        this.isSystemTask = isSystemTask;
    }

    /*
     * TODO: Update code to use only enums rather than Strings.
     * This method is only used as a helper until the transition is done.
     */
    public static boolean isSystemTask(String name) {
        try {
            TaskType taskType = TaskType.valueOf(name);
            return taskType.isSystemTask;
        } catch (IllegalArgumentException iae) {
            return false;
        }
    }
}

==> conductor-common-2.7.2-sources.jar: com/netflix/conductor/common/metadata/workflow/TaskType.java <==
package com.netflix.conductor.common.metadata.workflow;

import com.github.vmg.protogen.annotations.ProtoEnum;

@ProtoEnum
public enum TaskType {

    SIMPLE(true),
    DYNAMIC(true),
    FORK_JOIN(true),
    FORK_JOIN_DYNAMIC(true),
    DECISION(true),
    JOIN(true),
    SUB_WORKFLOW(true),
    EVENT(true),
    WAIT(true),
    USER_DEFINED(false),
    HTTP(true);

    /**
     * TaskType constants representing each of the possible enumeration values.
     * Motivation: to not have any hardcoded/inline strings used in the code.
     * Example of use: CoreModule
     */
    public static final String TASK_TYPE_DECISION = "DECISION";
    public static final String TASK_TYPE_DYNAMIC = "DYNAMIC";
    public static final String TASK_TYPE_JOIN = "JOIN";
    public static final String TASK_TYPE_FORK_JOIN_DYNAMIC = "FORK_JOIN_DYNAMIC";
    public static final String TASK_TYPE_EVENT = "EVENT";
    public static final String TASK_TYPE_WAIT = "WAIT";
    public static final String TASK_TYPE_SUB_WORKFLOW = "SUB_WORKFLOW";
    public static final String TASK_TYPE_FORK_JOIN = "FORK_JOIN";
    public static final String TASK_TYPE_USER_DEFINED = "USER_DEFINED";
    public static final String TASK_TYPE_SIMPLE = "SIMPLE";
    public static final String TASK_TYPE_HTTP = "HTTP";

    private boolean isSystemTask;

    TaskType(boolean isSystemTask) {
        this.isSystemTask = isSystemTask;
    }

    /*
     * TODO: Update code to use only enums rather than Strings.
     * This method is only used as a helper until the transition is done.
     */
    public static boolean isSystemTask(String name) {
        try {
            TaskType taskType = TaskType.valueOf(name);
            return taskType.isSystemTask;
        } catch (IllegalArgumentException iae) {
            return false;
        }
    }
}
